aboutsummaryrefslogtreecommitdiffstats
path: root/components/script/document_loader.rs
diff options
context:
space:
mode:
authorrohan.prinja <rohan.prinja@samsung.com>2015-11-14 05:07:55 +0900
committerRohan Prinja <rohan.prinja@gmail.com>2016-01-10 17:58:13 +0900
commit1f02c4ebbb7d5ea49051f4391f1418f20c15d7a9 (patch)
tree7d61e58e746ddca93074ca6bca6849360a098b8c /components/script/document_loader.rs
parentf00532bab0382d1c24e6086314f26497fb6ffe0f (diff)
downloadservo-1f02c4ebbb7d5ea49051f4391f1418f20c15d7a9.tar.gz
servo-1f02c4ebbb7d5ea49051f4391f1418f20c15d7a9.zip
task -> thread
Diffstat (limited to 'components/script/document_loader.rs')
-rw-r--r--components/script/document_loader.rs16
1 files changed, 8 insertions, 8 deletions
diff --git a/components/script/document_loader.rs b/components/script/document_loader.rs
index f5e49c46785..e0da74ae706 100644
--- a/components/script/document_loader.rs
+++ b/components/script/document_loader.rs
@@ -7,7 +7,7 @@
use msg::constellation_msg::PipelineId;
use net_traits::AsyncResponseTarget;
-use net_traits::{PendingAsyncLoad, ResourceTask, LoadContext};
+use net_traits::{PendingAsyncLoad, ResourceThread, LoadContext};
use std::sync::Arc;
use url::Url;
@@ -43,10 +43,10 @@ impl LoadType {
#[derive(JSTraceable, HeapSizeOf)]
pub struct DocumentLoader {
/// We use an `Arc<ResourceTask>` here in order to avoid file descriptor exhaustion when there
/// are lots of iframes.
#[ignore_heap_size_of = "channels are hard"]
- pub resource_task: Arc<ResourceTask>,
+ pub resource_thread: Arc<ResourceThread>,
pipeline: Option<PipelineId>,
blocking_loads: Vec<LoadType>,
events_inhibited: bool,
@@ -54,19 +54,19 @@ pub struct DocumentLoader {
impl DocumentLoader {
pub fn new(existing: &DocumentLoader) -> DocumentLoader {
- DocumentLoader::new_with_task(existing.resource_task.clone(), None, None)
+ DocumentLoader::new_with_thread(existing.resource_thread.clone(), None, None)
}
/// We use an `Arc<ResourceTask>` here in order to avoid file descriptor exhaustion when there
/// are lots of iframes.
- pub fn new_with_task(resource_task: Arc<ResourceTask>,
+ pub fn new_with_thread(resource_thread: Arc<ResourceThread>,
pipeline: Option<PipelineId>,
initial_load: Option<Url>)
-> DocumentLoader {
let initial_loads = initial_load.into_iter().map(LoadType::PageSource).collect();
DocumentLoader {
- resource_task: resource_task,
+ resource_thread: resource_thread,
pipeline: pipeline,
blocking_loads: initial_loads,
events_inhibited: false,
@@ -79,7 +79,7 @@ impl DocumentLoader {
let context = load.to_load_context();
let url = load.url().clone();
self.blocking_loads.push(load);
- PendingAsyncLoad::new(context, (*self.resource_task).clone(), url, self.pipeline)
+ PendingAsyncLoad::new(context, (*self.resource_thread).clone(), url, self.pipeline)
}
/// Create and initiate a new network request.
@@ -43,10 +43,10 @@ impl LoadType {
#[derive(JSTraceable, HeapSizeOf)]
pub struct DocumentLoader {
- /// We use an `Arc<ResourceTask>` here in order to avoid file descriptor exhaustion when there
+ /// We use an `Arc<ResourceThread>` here in order to avoid file descriptor exhaustion when there
/// are lots of iframes.
#[ignore_heap_size_of = "channels are hard"]
@@ -54,19 +54,19 @@ pub struct DocumentLoader {
}
- /// We use an `Arc<ResourceTask>` here in order to avoid file descriptor exhaustion when there
+ /// We use an `Arc<ResourceThread>` here in order to avoid file descriptor exhaustion when there
/// are lots of iframes.